@@ -18,8 +18,8 @@ getSVCSamples <- function(object, pred.object, ...) {
   if (!(class(object) %in% c('svcPGOcc', 'svcPGBinom', 
 			     'svcTPGOcc', 'svcTPGBinom', 
 			     'svcMsPGOcc', 'svcTMsPGOcc', 
-			     'svcAbund', 'svcMsAbund'))) {
-    stop("error: object must be of class svcPGOcc, svcPGBinom, svcTPGOcc, svcTPGBinom, svcMsPGOcc, svcTMsPGOcc\n")
+			     'svcAbund', 'svcMsAbund', 'svcTIntPGOcc'))) {
+    stop("error: object must be of class svcPGOcc, svcPGBinom, svcTPGOcc, svcTPGBinom, svcMsPGOcc, svcTMsPGOcc, svcTIntPGOcc\n")
   }
 
   n.post <- object$n.post * object$n.chains
@@ -37,7 +37,7 @@ getSVCSamples <- function(object, pred.object, ...) {
   p.svc <- length(svc.cols)
   # Single-species models -------------------------------------------------
   if (class(object) %in% c('svcPGOcc', 'svcPGBinom', 
-			   'svcTPGOcc', 'svcTPGBinom', 'svcAbund')) {
+			   'svcTPGOcc', 'svcTPGBinom', 'svcAbund', 'svcTIntPGOcc')) {
     if (!missing(pred.object)) {
       svc.samples <- lapply(svc.cols, function(a) mcmc(object$beta.samples[, a] + pred.object$w.0.samples[, which(svc.cols == a), ]))
     } else {
