@@ -10,7 +10,13 @@ simTBinom <- function(J.x, J.y, n.time, weights, beta, sp.only = 0,
       if(! i %in% formal.args)
           warning("'",i, "' is not an argument")
   }
-
+  # Subroutines -----------------------------------------------------------
+  rmvn <- function(n, mu=0, V = matrix(1)){
+    p <- length(mu)
+    if(any(is.na(match(dim(V),p)))){stop("Dimension problem!")}
+    D <- chol(V)
+    t(matrix(rnorm(n*p), ncol=p)%*%D + rep(mu,rep(n,p)))
+  }
   # Check function inputs -------------------------------------------------
   # J.x -------------------------------
   if (missing(J.x)) {
@@ -143,7 +149,7 @@ simTBinom <- function(J.x, J.y, n.time, weights, beta, sp.only = 0,
   if (x.positive) {
     if (p.occ > 1) {
       for (i in 2:p.occ) {
-        X[, , i] <- abs(min(X[, , i])) + X[, , i]
+        X[, , i] <- runif(J * n.time.max, 0, 1) 
       }
     }
   }
@@ -197,7 +203,7 @@ simTBinom <- function(J.x, J.y, n.time, weights, beta, sp.only = 0,
     for (i in 1:p.svc) {
       Sigma <- mkSpCov(coords, as.matrix(sigma.sq[i]), as.matrix(0), theta[i, ], cov.model)
       # Random spatial process
-      w.mat[, i] <- mvrnorm(1, rep(0, J), Sigma)
+      w.mat[, i] <- rmvn(1, rep(0, J), Sigma)
     }
     X.w <- X[, , svc.cols, drop = FALSE]
     w.sites <- matrix(0, J, n.time.max)
@@ -216,7 +222,7 @@ simTBinom <- function(J.x, J.y, n.time, weights, beta, sp.only = 0,
     exponent <- abs(matrix(1:n.time.max - 1, nrow = n.time.max, 
 			   ncol = n.time.max, byrow = TRUE) - (1:n.time.max - 1))
     Sigma.eta <- sigma.sq.t * rho^exponent
-    eta <- mvrnorm(1, rep(0, n.time.max), Sigma.eta)
+    eta <- rmvn(1, rep(0, n.time.max), Sigma.eta)
   } else {
     eta <- matrix(rep(0, n.time.max))
   }
