@@ -1,11 +1,12 @@
 spPGOcc <- function(occ.formula, det.formula, data, inits, priors, 
-		    tuning, cov.model = 'exponential', NNGP = TRUE, 
-		    n.neighbors = 15, search.type = 'cb', n.batch, 
-		    batch.length, accept.rate = 0.43,
-		    n.omp.threads = 1, verbose = TRUE, n.report = 100, 
-		    n.burn = round(.10 * n.batch * batch.length), 
-		    n.thin = 1, n.chains = 1, k.fold, k.fold.threads = 1, 
-		    k.fold.seed = 100, k.fold.only = FALSE, ...){
+                    tuning, cov.model = 'exponential', NNGP = TRUE, 
+                    n.neighbors = 15, search.type = 'cb', n.batch, 
+                    batch.length, accept.rate = 0.43,
+                    n.omp.threads = 1, verbose = TRUE, n.report = 100, 
+                    n.burn = round(.10 * n.batch * batch.length), 
+                    n.thin = 1, n.chains = 1, 
+                    k.fold, k.fold.threads = 1, k.fold.seed = 100, 
+                    k.fold.only = FALSE, ...){
 
   ptm <- proc.time()
 
@@ -795,7 +796,7 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
       }
     }
     beta.star.indx <- rep(0:(p.occ.re - 1), n.occ.re.long)
-    beta.star.inits <- rnorm(n.occ.re, sqrt(sigma.sq.psi.inits[beta.star.indx + 1]))
+    beta.star.inits <- rnorm(n.occ.re, 0, sqrt(sigma.sq.psi.inits[beta.star.indx + 1]))
   } else {
     sigma.sq.psi.inits <- 0
     beta.star.indx <- 0
@@ -825,7 +826,7 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
       }
     }
     alpha.star.indx <- rep(0:(p.det.re - 1), n.det.re.long)
-    alpha.star.inits <- rnorm(n.det.re, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
+    alpha.star.inits <- rnorm(n.det.re, 0, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
   } else {
     sigma.sq.p.inits <- 0
     alpha.star.indx <- 0
@@ -1004,13 +1005,13 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
           if (p.det.re > 0) {
             if (!fixed.params[which(all.params == 'sigma.sq.p')]) {
               sigma.sq.p.inits <- runif(p.det.re, 0.5, 10)
-              alpha.star.inits <- rnorm(n.det.re, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
+              alpha.star.inits <- rnorm(n.det.re, 0, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
             }
           }
           if (p.occ.re > 0) {
             if (!fixed.params[which(all.params == 'sigma.sq.psi')]) {
               sigma.sq.psi.inits <- runif(p.occ.re, 0.5, 10)
-              beta.star.inits <- rnorm(n.occ.re, sqrt(sigma.sq.psi.inits[beta.star.indx + 1]))
+              beta.star.inits <- rnorm(n.occ.re, 0, sqrt(sigma.sq.psi.inits[beta.star.indx + 1]))
             }
           }
         }
@@ -1022,10 +1023,10 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
         	                    beta.star.inits, alpha.star.inits, z.inits,
                               w.inits, phi.inits, sigma.sq.inits, nu.inits, z.long.indx, 
                               beta.star.indx, beta.level.indx, alpha.star.indx, 
-          		    alpha.level.indx, mu.beta, mu.alpha, 
+                              alpha.level.indx, mu.beta, mu.alpha, 
                               Sigma.beta, Sigma.alpha, phi.a, phi.b, 
                               sigma.sq.a, sigma.sq.b, nu.a, nu.b, 
-          		    sigma.sq.psi.a, sigma.sq.psi.b, sigma.sq.p.a, sigma.sq.p.b, 
+                              sigma.sq.psi.a, sigma.sq.psi.b, sigma.sq.p.a, sigma.sq.p.b, 
         	                    tuning.c, cov.model.indx,
                               n.batch, batch.length, 
                               accept.rate, n.omp.threads, verbose, n.report, 
@@ -1190,7 +1191,7 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
         if (p.det.re > 0) {	
           alpha.star.indx.fit <- rep(0:(p.det.re - 1), n.det.re.long.fit)
           alpha.level.indx.fit <- sort(unique(c(X.p.re.fit)))
-          alpha.star.inits.fit <- rnorm(n.det.re.fit, 
+          alpha.star.inits.fit <- rnorm(n.det.re.fit, 0,
           			      sqrt(sigma.sq.p.inits[alpha.star.indx.fit + 1]))
           p.re.level.names.fit <- list()
           for (t in 1:p.det.re) {
@@ -1210,7 +1211,7 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
         if (p.occ.re > 0) {	
           beta.star.indx.fit <- rep(0:(p.occ.re - 1), n.occ.re.long.fit)
           beta.level.indx.fit <- sort(unique(c(X.re.fit)))
-          beta.star.inits.fit <- rnorm(n.occ.re.fit, 
+          beta.star.inits.fit <- rnorm(n.occ.re.fit, 0,
           			      sqrt(sigma.sq.psi.inits[beta.star.indx.fit + 1]))
           re.level.names.fit <- list()
           for (t in 1:p.occ.re) {
@@ -1525,13 +1526,13 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
           if (p.det.re > 0) {
             if (!fixed.params[which(all.params == 'sigma.sq.p')]) {
               sigma.sq.p.inits <- runif(p.det.re, 0.5, 10)
-              alpha.star.inits <- rnorm(n.det.re, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
+              alpha.star.inits <- rnorm(n.det.re, 0, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
             }
           }
           if (p.occ.re > 0) {
             if (!fixed.params[which(all.params == 'sigma.sq.psi')]) {
               sigma.sq.psi.inits <- runif(p.occ.re, 0.5, 10)
-              beta.star.inits <- rnorm(n.occ.re, sqrt(sigma.sq.psi.inits[beta.star.indx + 1]))
+              beta.star.inits <- rnorm(n.occ.re, 0, sqrt(sigma.sq.psi.inits[beta.star.indx + 1]))
             }
           }
         }
@@ -1539,15 +1540,15 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
         # Run the model in C    
         out.tmp[[i]] <- .Call("spPGOccNNGP", y, X, X.p, coords, X.re, X.p.re, consts, 
         	                    K, n.occ.re.long, n.det.re.long, 
-            	            n.neighbors, nn.indx, nn.indx.lu, u.indx, u.indx.lu, ui.indx, 
+                              n.neighbors, nn.indx, nn.indx.lu, u.indx, u.indx.lu, ui.indx, 
                               beta.inits, alpha.inits, sigma.sq.psi.inits, sigma.sq.p.inits, 
         	                    beta.star.inits, alpha.star.inits, z.inits,
                               w.inits, phi.inits, sigma.sq.inits, nu.inits, z.long.indx, 
                               beta.star.indx, beta.level.indx, alpha.star.indx, 
-          		    alpha.level.indx, mu.beta, mu.alpha, 
+                              alpha.level.indx, mu.beta, mu.alpha, 
                               Sigma.beta, Sigma.alpha, phi.a, phi.b, 
                               sigma.sq.a, sigma.sq.b, nu.a, nu.b, 
-          		    sigma.sq.psi.a, sigma.sq.psi.b, sigma.sq.p.a, sigma.sq.p.b, 
+                              sigma.sq.psi.a, sigma.sq.psi.b, sigma.sq.p.a, sigma.sq.p.b, 
         	                    tuning.c, cov.model.indx,
                               n.batch, batch.length, 
                               accept.rate, n.omp.threads, verbose, n.report, 
@@ -1749,7 +1750,7 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
         if (p.det.re > 0) {	
           alpha.star.indx.fit <- rep(0:(p.det.re - 1), n.det.re.long.fit)
           alpha.level.indx.fit <- sort(unique(c(X.p.re.fit)))
-          alpha.star.inits.fit <- rnorm(n.det.re.fit, 
+          alpha.star.inits.fit <- rnorm(n.det.re.fit, 0,
           			      sqrt(sigma.sq.p.inits[alpha.star.indx.fit + 1]))
           p.re.level.names.fit <- list()
           for (t in 1:p.det.re) {
@@ -1769,7 +1770,7 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
         if (p.occ.re > 0) {	
           beta.star.indx.fit <- rep(0:(p.occ.re - 1), n.occ.re.long.fit)
           beta.level.indx.fit <- sort(unique(c(X.re.fit)))
-          beta.star.inits.fit <- rnorm(n.occ.re.fit, 
+          beta.star.inits.fit <- rnorm(n.occ.re.fit, 0,
           			      sqrt(sigma.sq.psi.inits[beta.star.indx.fit + 1]))
           re.level.names.fit <- list()
           for (t in 1:p.occ.re) {
@@ -1957,7 +1958,6 @@ spPGOcc <- function(occ.formula, det.formula, data, inits, priors,
       model.deviance <- -2 * model.deviance
       # Return objects from cross-validation
       out$k.fold.deviance <- model.deviance
-      stopImplicitCluster()
     } # cross-validation
   } # NNGP or GP
   class(out) <- "spPGOcc"
