@@ -303,7 +303,7 @@ stMsPGOcc <- function(occ.formula, det.formula, data, inits, priors,
   if (p.det.re == 0) n.det.re.long <- 0
   # Number of repeat visits
   n.rep <- apply(y.big[1, , , , drop = FALSE], c(2, 3), function(a) sum(!is.na(a)))
-  K.max <- max(n.rep)
+  K.max <- dim(y.big)[4]
   # Because I like K better than n.rep
   K <- n.rep
   if (missing(n.batch)) {
@@ -1026,7 +1026,7 @@ stMsPGOcc <- function(occ.formula, det.formula, data, inits, priors,
       }
     }
     beta.star.indx <- rep(0:(p.occ.re - 1), n.occ.re.long)
-    beta.star.inits <- rnorm(n.occ.re, sqrt(sigma.sq.psi.inits[beta.star.indx + 1]))
+    beta.star.inits <- rnorm(n.occ.re, 0, sqrt(sigma.sq.psi.inits[beta.star.indx + 1]))
     beta.star.inits <- rep(beta.star.inits, N)
   } else {
     sigma.sq.psi.inits <- 0
@@ -1058,7 +1058,7 @@ stMsPGOcc <- function(occ.formula, det.formula, data, inits, priors,
       }
     }
     alpha.star.indx <- rep(0:(p.det.re - 1), n.det.re.long)
-    alpha.star.inits <- rnorm(n.det.re, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
+    alpha.star.inits <- rnorm(n.det.re, 0, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
     alpha.star.inits <- rep(alpha.star.inits, N)
   } else {
     sigma.sq.p.inits <- 0
@@ -1350,12 +1350,12 @@ stMsPGOcc <- function(occ.formula, det.formula, data, inits, priors,
         }
         if (p.det.re > 0) {
           sigma.sq.p.inits <- runif(p.det.re, 0.5, 10)
-          alpha.star.inits <- rnorm(n.det.re, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
+          alpha.star.inits <- rnorm(n.det.re, 0, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
           alpha.star.inits <- rep(alpha.star.inits, N)
         }
         if (p.occ.re > 0) {
           sigma.sq.psi.inits <- runif(p.occ.re, 0.5, 10)
-          beta.star.inits <- rnorm(n.occ.re, sqrt(sigma.sq.psi.inits[beta.star.indx + 1]))
+          beta.star.inits <- rnorm(n.occ.re, 0, sqrt(sigma.sq.psi.inits[beta.star.indx + 1]))
           beta.star.inits <- rep(beta.star.inits, N)
         }
         if (ar1) {
@@ -1370,25 +1370,25 @@ stMsPGOcc <- function(occ.formula, det.formula, data, inits, priors,
       storage.mode(chain.info) <- "integer"
       # Run the model in C
       out.tmp[[i]] <- .Call("stMsPGOccNNGP", y, X, X.p, 
-      		      coords, X.re, X.p.re, consts, 
-        		    n.occ.re.long, n.det.re.long, 
-        	            n.neighbors, nn.indx, nn.indx.lu, u.indx, u.indx.lu, ui.indx,
-        	            beta.inits, alpha.inits, z.inits,
-        	            beta.comm.inits, 
-        	            alpha.comm.inits, tau.sq.beta.inits, 
-        	            tau.sq.alpha.inits, phi.inits, 
-        	            lambda.inits, nu.inits, sigma.sq.psi.inits, sigma.sq.p.inits, 
-        		    beta.star.inits, alpha.star.inits, z.long.indx, z.year.indx, 
-      		    z.dat.indx, z.site.indx,
-        		    beta.star.indx, beta.level.indx, alpha.star.indx, 
-        		    alpha.level.indx, beta.comm.priors, 
-        	            alpha.comm.priors, tau.sq.beta.priors, 
-			    tau.sq.alpha.priors, phi.priors, nu.priors,  
-        	            sigma.sq.psi.a, sigma.sq.psi.b, 
-        		    sigma.sq.p.a, sigma.sq.p.b, 
-        		    tuning.c, cov.model.indx, n.batch, 
-        	            batch.length, accept.rate, n.omp.threads, verbose, n.report, 
-        	            samples.info, chain.info, ar1.vals, grid.index.c)
+                            coords, X.re, X.p.re, consts, 
+                            n.occ.re.long, n.det.re.long, 
+        	                  n.neighbors, nn.indx, nn.indx.lu, u.indx, u.indx.lu, ui.indx,
+        	                  beta.inits, alpha.inits, z.inits,
+        	                  beta.comm.inits, 
+        	                  alpha.comm.inits, tau.sq.beta.inits, 
+        	                  tau.sq.alpha.inits, phi.inits, 
+        	                  lambda.inits, nu.inits, sigma.sq.psi.inits, sigma.sq.p.inits, 
+                            beta.star.inits, alpha.star.inits, z.long.indx, z.year.indx, 
+                            z.dat.indx, z.site.indx,
+                            beta.star.indx, beta.level.indx, alpha.star.indx, 
+                            alpha.level.indx, beta.comm.priors, 
+                            alpha.comm.priors, tau.sq.beta.priors, 
+                            tau.sq.alpha.priors, phi.priors, nu.priors,  
+                            sigma.sq.psi.a, sigma.sq.psi.b, 
+                            sigma.sq.p.a, sigma.sq.p.b, 
+                            tuning.c, cov.model.indx, n.batch, 
+                            batch.length, accept.rate, n.omp.threads, verbose, n.report, 
+                            samples.info, chain.info, ar1.vals, grid.index.c)
       chain.info[1] <- chain.info[1] + 1
     }
     # Calculate R-Hat ---------------
