@@ -1,11 +1,12 @@
 stPGOcc <- function(occ.formula, det.formula, data, inits, priors, 
-		     tuning, cov.model = 'exponential', NNGP = TRUE, 
-		     n.neighbors = 15, search.type = 'cb', n.batch, 
-		     batch.length, accept.rate = 0.43, n.omp.threads = 1, 
-		     verbose = TRUE, ar1 = FALSE, n.report = 100, 
-		     n.burn = round(.10 * n.batch * batch.length), 
-		     n.thin = 1, n.chains = 1, k.fold, k.fold.threads = 1, 
-		     k.fold.seed = 100, k.fold.only = FALSE, ...){
+                    tuning, cov.model = 'exponential', NNGP = TRUE, 
+                    n.neighbors = 15, search.type = 'cb', n.batch, 
+                    batch.length, accept.rate = 0.43, n.omp.threads = 1, 
+                    verbose = TRUE, ar1 = FALSE, n.report = 100, 
+                    n.burn = round(.10 * n.batch * batch.length), 
+                    n.thin = 1, n.chains = 1, 
+                    k.fold, k.fold.threads = 1, k.fold.seed = 100, 
+                    k.fold.only = FALSE, ...){
 
   ptm <- proc.time()
 
@@ -854,7 +855,7 @@ stPGOcc <- function(occ.formula, det.formula, data, inits, priors,
       }
     }
     beta.star.indx <- rep(0:(p.occ.re - 1), n.occ.re.long)
-    beta.star.inits <- rnorm(n.occ.re, sqrt(sigma.sq.psi.inits[beta.star.indx + 1]))
+    beta.star.inits <- rnorm(n.occ.re, 0, sqrt(sigma.sq.psi.inits[beta.star.indx + 1]))
   } else {
     sigma.sq.psi.inits <- 0
     beta.star.indx <- 0
@@ -884,7 +885,7 @@ stPGOcc <- function(occ.formula, det.formula, data, inits, priors,
       }
     }
     alpha.star.indx <- rep(0:(p.det.re - 1), n.det.re.long)
-    alpha.star.inits <- rnorm(n.det.re, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
+    alpha.star.inits <- rnorm(n.det.re, 0, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
   } else {
     sigma.sq.p.inits <- 0
     alpha.star.indx <- 0
@@ -1150,25 +1151,25 @@ stPGOcc <- function(occ.formula, det.formula, data, inits, priors,
           alpha.inits <- rnorm(p.det, mu.alpha, sqrt(sigma.alpha))
           if (sigma.sq.ig) {
             sigma.sq.inits <- rigamma(1, sigma.sq.a, sigma.sq.b)
-	  } else {
+          } else {
             sigma.sq.inits <- runif(1, sigma.sq.a, sigma.sq.b)
-	  }
+          }
           phi.inits <- runif(1, phi.a, phi.b)
           if (cov.model == 'matern') {
             nu.inits <- runif(1, nu.a, nu.b)
           }
           if (p.det.re > 0) {
             sigma.sq.p.inits <- runif(p.det.re, 0.5, 10)
-            alpha.star.inits <- rnorm(n.det.re, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
+            alpha.star.inits <- rnorm(n.det.re, 0, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
           }
           if (p.occ.re > 0) {
             sigma.sq.psi.inits <- runif(p.occ.re, 0.5, 10)
-            beta.star.inits <- rnorm(n.occ.re, sqrt(sigma.sq.psi.inits[beta.star.indx + 1]))
+            beta.star.inits <- rnorm(n.occ.re, 0, sqrt(sigma.sq.psi.inits[beta.star.indx + 1]))
           }
-	  if (ar1) {
+          if (ar1) {
             ar1.vals[5] <- runif(1, rho.a, rho.b)
             ar1.vals[6] <- runif(1, 0.5, 10)	
-	  }
+          }
         }
         storage.mode(curr.chain) <- "integer"
         # Note that the upper limit on the number of arguments is 65, which 
@@ -1178,7 +1179,7 @@ stPGOcc <- function(occ.formula, det.formula, data, inits, priors,
                               n.neighbors, nn.indx, nn.indx.lu, u.indx, u.indx.lu, ui.indx,
                               beta.inits, alpha.inits, sigma.sq.psi.inits, 
                               sigma.sq.p.inits, beta.star.inits, alpha.star.inits, 
-          		      phi.inits, sigma.sq.inits, nu.inits,
+                              phi.inits, sigma.sq.inits, nu.inits,
                               w.inits, z.inits, z.long.indx, z.year.indx,
                               z.dat.indx, z.long.site.indx, 
                               beta.star.indx, beta.level.indx,
@@ -1186,32 +1187,30 @@ stPGOcc <- function(occ.formula, det.formula, data, inits, priors,
                               mu.beta, Sigma.beta, mu.alpha, Sigma.alpha, 
                               phi.a, phi.b, sigma.sq.a, sigma.sq.b, nu.a, nu.b,
                               sigma.sq.psi.a, sigma.sq.psi.b, sigma.sq.p.a, sigma.sq.p.b,
-			      ar1, ar1.vals,
-                              tuning.c, cov.model.indx, n.batch, batch.length, accept.rate, 
+                              ar1, ar1.vals, tuning.c, cov.model.indx, 
+                              n.batch, batch.length, accept.rate, 
                               n.omp.threads, verbose, n.report,  
                               n.burn, n.thin, n.post.samples, curr.chain, n.chains, sigma.sq.ig, 
                               grid.index.c)
         curr.chain <- curr.chain + 1
       }
-      out <- list()
-
       # Calculate R-Hat ---------------
       if (ar1) {
         if (cov.model == 'matern') {
           n.theta <- 5
           theta.names <- c('sigma.sq', 'phi', 'nu', 'sigma.sq.t', 'rho')
-	} else {
+        } else {
           n.theta <- 4
           theta.names <- c('sigma.sq', 'phi', 'sigma.sq.t', 'rho')
-	}
+        }
       } else {
         if (cov.model == 'matern') {
           n.theta <- 3
           theta.names <- c('sigma.sq', 'phi', 'nu')
-	} else {
+        } else {
           n.theta <- 2
           theta.names <- c('sigma.sq', 'phi')
-	}
+        }
       }
       out <- list()
       out$rhat <- list()
@@ -1410,7 +1409,7 @@ stPGOcc <- function(occ.formula, det.formula, data, inits, priors,
         if (p.det.re > 0) {	
           alpha.star.indx.fit <- rep(0:(p.det.re - 1), n.det.re.long.fit)
           alpha.level.indx.fit <- sort(unique(c(X.p.re.fit)))
-          alpha.star.inits.fit <- rnorm(n.det.re.fit, 
+          alpha.star.inits.fit <- rnorm(n.det.re.fit, 0,
           			      sqrt(sigma.sq.p.inits[alpha.star.indx.fit + 1]))
           p.re.level.names.fit <- list()
           for (t in 1:p.det.re) {
@@ -1430,7 +1429,7 @@ stPGOcc <- function(occ.formula, det.formula, data, inits, priors,
         if (p.occ.re > 0) {	
           beta.star.indx.fit <- rep(0:(p.occ.re - 1), n.occ.re.long.fit)
           beta.level.indx.fit <- sort(unique(c(X.re.fit)))
-          beta.star.inits.fit <- rnorm(n.occ.re.fit, 
+          beta.star.inits.fit <- rnorm(n.occ.re.fit, 0,
           			      sqrt(sigma.sq.psi.inits[beta.star.indx.fit + 1]))
           re.level.names.fit <- list()
           for (t in 1:p.occ.re) {
