@@ -1,8 +1,9 @@
 tPGOcc <- function(occ.formula, det.formula, data, inits, priors, tuning,
-		   n.batch, batch.length, accept.rate = 0.43, n.omp.threads = 1, verbose = TRUE, ar1 = FALSE,
-		   n.report = 100, n.burn = round(.10 * n.batch * batch.length), n.thin = 1, 
-		   n.chains = 1, k.fold, k.fold.threads = 1, k.fold.seed = 100, 
-		   k.fold.only = FALSE, ...){
+                   n.batch, batch.length, accept.rate = 0.43, n.omp.threads = 1, 
+                   verbose = TRUE, ar1 = FALSE, n.report = 100, 
+                   n.burn = round(.10 * n.batch * batch.length), n.thin = 1, 
+                   n.chains = 1, k.fold, k.fold.threads = 1, k.fold.seed = 100, 
+                   k.fold.only = FALSE, ...){
 
   ptm <- proc.time()
 
@@ -642,7 +643,7 @@ tPGOcc <- function(occ.formula, det.formula, data, inits, priors, tuning,
       }
     }
     beta.star.indx <- rep(0:(p.occ.re - 1), n.occ.re.long)
-    beta.star.inits <- rnorm(n.occ.re, sqrt(sigma.sq.psi.inits[beta.star.indx + 1]))
+    beta.star.inits <- rnorm(n.occ.re, 0, sqrt(sigma.sq.psi.inits[beta.star.indx + 1]))
   } else {
     sigma.sq.psi.inits <- 0
     beta.star.indx <- 0
@@ -672,7 +673,7 @@ tPGOcc <- function(occ.formula, det.formula, data, inits, priors, tuning,
       }
     }
     alpha.star.indx <- rep(0:(p.det.re - 1), n.det.re.long)
-    alpha.star.inits <- rnorm(n.det.re, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
+    alpha.star.inits <- rnorm(n.det.re, 0, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
   } else {
     sigma.sq.p.inits <- 0
     alpha.star.indx <- 0
@@ -808,8 +809,8 @@ tPGOcc <- function(occ.formula, det.formula, data, inits, priors, tuning,
 
   # tPGOcc
   out <- list()
+  out.tmp <- list()
   if (!k.fold.only) {
-    out.tmp <- list()
     for (i in 1:n.chains) {
       # Change initial values if i > 1
       if ((i > 1) & (!fix.inits)) {
@@ -817,16 +818,16 @@ tPGOcc <- function(occ.formula, det.formula, data, inits, priors, tuning,
         alpha.inits <- rnorm(p.det, mu.alpha, sqrt(sigma.alpha))
         if (p.det.re > 0) {
           sigma.sq.p.inits <- runif(p.det.re, 0.5, 10)
-          alpha.star.inits <- rnorm(n.det.re, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
+          alpha.star.inits <- rnorm(n.det.re, 0, sqrt(sigma.sq.p.inits[alpha.star.indx + 1]))
         }
         if (p.occ.re > 0) {
           sigma.sq.psi.inits <- runif(p.occ.re, 0.5, 10)
-          beta.star.inits <- rnorm(n.occ.re, sqrt(sigma.sq.psi.inits[beta.star.indx + 1]))
+          beta.star.inits <- rnorm(n.occ.re, 0, sqrt(sigma.sq.psi.inits[beta.star.indx + 1]))
         }
-	if (ar1) {
+        if (ar1) {
           ar1.vals[5] <- runif(1, rho.a, rho.b)
           ar1.vals[6] <- runif(1, 0.5, 10)	
-	}
+        }
       }
       storage.mode(curr.chain) <- "integer"
       out.tmp[[i]] <- .Call("tPGOcc", y, X, X.p, X.re, X.p.re, 
@@ -839,13 +840,12 @@ tPGOcc <- function(occ.formula, det.formula, data, inits, priors, tuning,
                             alpha.star.indx, alpha.level.indx,
                             mu.beta, Sigma.beta, mu.alpha, Sigma.alpha, 
                             sigma.sq.psi.a, sigma.sq.psi.b, sigma.sq.p.a, sigma.sq.p.b,
-			    ar1, ar1.vals, tuning.c,
+                            ar1, ar1.vals, tuning.c,
                             n.batch, batch.length, accept.rate, 
-			    n.omp.threads, verbose, n.report,  
+                            n.omp.threads, verbose, n.report,  
                             n.burn, n.thin, n.post.samples, curr.chain, n.chains)
       curr.chain <- curr.chain + 1
     }
-
     # Calculate R-Hat ---------------
     out$rhat <- list()
     if (n.chains > 1) {
@@ -1010,7 +1010,7 @@ tPGOcc <- function(occ.formula, det.formula, data, inits, priors, tuning,
       if (p.det.re > 0) {	
         alpha.star.indx.fit <- rep(0:(p.det.re - 1), n.det.re.long.fit)
         alpha.level.indx.fit <- sort(unique(c(X.p.re.fit)))
-        alpha.star.inits.fit <- rnorm(n.det.re.fit, 
+        alpha.star.inits.fit <- rnorm(n.det.re.fit, 0,
         			      sqrt(sigma.sq.p.inits[alpha.star.indx.fit + 1]))
         p.re.level.names.fit <- list()
         for (t in 1:p.det.re) {
@@ -1030,7 +1030,7 @@ tPGOcc <- function(occ.formula, det.formula, data, inits, priors, tuning,
       if (p.occ.re > 0) {	
         beta.star.indx.fit <- rep(0:(p.occ.re - 1), n.occ.re.long.fit)
         beta.level.indx.fit <- sort(unique(c(X.re.fit)))
-        beta.star.inits.fit <- rnorm(n.occ.re.fit, 
+        beta.star.inits.fit <- rnorm(n.occ.re.fit, 0,
         			      sqrt(sigma.sq.psi.inits[beta.star.indx.fit + 1]))
         re.level.names.fit <- list()
         for (t in 1:p.occ.re) {
