@@ -16,9 +16,9 @@ static const R_CallMethodDef CallEntries[] = {
     {"spMsPGOccNNGP", (DL_FUNC) &spMsPGOccNNGP, 65},
     {"spMsPGOccPredict", (DL_FUNC) &spMsPGOccPredict, 18},
     {"spMsPGOccNNGPPredict", (DL_FUNC) &spMsPGOccNNGPPredict, 20},
-    {"intPGOcc", (DL_FUNC) &intPGOcc, 31},
-    {"spIntPGOcc", (DL_FUNC) &spIntPGOcc, 48},
-    {"spIntPGOccNNGP", (DL_FUNC) &spIntPGOccNNGP, 54},
+    {"intPGOcc", (DL_FUNC) &intPGOcc, 45},
+    {"spIntPGOcc", (DL_FUNC) &spIntPGOcc, 59},
+    {"spIntPGOccNNGP", (DL_FUNC) &spIntPGOccNNGP, 65},
     {"lfMsPGOcc", (DL_FUNC) &lfMsPGOcc, 44},
     {"sfMsPGOccNNGP", (DL_FUNC) &sfMsPGOccNNGP, 63},
     {"sfMsPGOccNNGPPredict", (DL_FUNC) &sfMsPGOccNNGPPredict, 26},
@@ -37,9 +37,13 @@ static const R_CallMethodDef CallEntries[] = {
     {"postHocLM", (DL_FUNC) &postHocLM, 21},
     {"svcMsPGOccNNGP", (DL_FUNC) &svcMsPGOccNNGP, 64},
     {"svcMsPGOccNNGPPredict", (DL_FUNC) &svcMsPGOccNNGPPredict, 24},
+    {"tMsPGOcc", (DL_FUNC) &tMsPGOcc, 50},
+    {"stMsPGOccNNGP", (DL_FUNC) &stMsPGOccNNGP, 59},
     {"svcTMsPGOccNNGP", (DL_FUNC) &svcTMsPGOccNNGP, 63},
     {"svcTMsPGOccNNGPPredict", (DL_FUNC) &svcTMsPGOccNNGPPredict, 29},
-    {"stMsPGOccNNGP", (DL_FUNC) &svcTMsPGOccNNGP, 59},
+    {"tIntPGOcc", (DL_FUNC) &tIntPGOcc, 52},
+    {"stIntPGOccNNGP", (DL_FUNC) &stIntPGOccNNGP, 60},
+    {"svcTIntPGOccNNGP", (DL_FUNC) &svcTIntPGOccNNGP, 60},
     {NULL, NULL, 0}
 };
 
