@@ -63,23 +63,23 @@ void updateBF1RE(double *B, double *F, double *c, double *C, double *coords, int
 
 extern "C" {
   SEXP spPGOccNNGP(SEXP y_r, SEXP X_r, SEXP Xp_r, SEXP coords_r, SEXP XRE_r, SEXP XpRE_r,
-	           SEXP consts_r, SEXP K_r, SEXP nOccRELong_r, SEXP nDetRELong_r, 
-		   SEXP m_r, SEXP nnIndx_r, 
-		   SEXP nnIndxLU_r, SEXP uIndx_r, SEXP uIndxLU_r, SEXP uiIndx_r,
-		   SEXP betaStarting_r, SEXP alphaStarting_r, SEXP sigmaSqPsiStarting_r,
-		   SEXP sigmaSqPStarting_r, SEXP betaStarStarting_r, SEXP alphaStarStarting_r, 
-	           SEXP zStarting_r, SEXP wStarting_r, SEXP phiStarting_r, 
-	           SEXP sigmaSqStarting_r, SEXP nuStarting_r, 
-	           SEXP zLongIndx_r, SEXP betaStarIndx_r, SEXP betaLevelIndx_r, 
-		   SEXP alphaStarIndx_r, SEXP alphaLevelIndx_r, SEXP muBeta_r, SEXP muAlpha_r, 
-	           SEXP SigmaBeta_r, SEXP SigmaAlpha_r, SEXP phiA_r, SEXP phiB_r, 
-	           SEXP sigmaSqA_r, SEXP sigmaSqB_r, SEXP nuA_r, SEXP nuB_r, 
-		   SEXP sigmaSqPsiA_r, SEXP sigmaSqPsiB_r, 
-		   SEXP sigmaSqPA_r, SEXP sigmaSqPB_r, 
-	           SEXP tuning_r, SEXP covModel_r, SEXP nBatch_r, 
-	           SEXP batchLength_r, SEXP acceptRate_r, SEXP nThreads_r, SEXP verbose_r, 
-	           SEXP nReport_r, SEXP samplesInfo_r, SEXP chainInfo_r, SEXP fixedParams_r, 
-		   SEXP sigmaSqIG_r, SEXP gridIndx_r){
+                   SEXP consts_r, SEXP K_r, SEXP nOccRELong_r, SEXP nDetRELong_r, 
+                   SEXP m_r, SEXP nnIndx_r, 
+                   SEXP nnIndxLU_r, SEXP uIndx_r, SEXP uIndxLU_r, SEXP uiIndx_r,
+                   SEXP betaStarting_r, SEXP alphaStarting_r, SEXP sigmaSqPsiStarting_r,
+                   SEXP sigmaSqPStarting_r, SEXP betaStarStarting_r, SEXP alphaStarStarting_r, 
+                   SEXP zStarting_r, SEXP wStarting_r, SEXP phiStarting_r, 
+                   SEXP sigmaSqStarting_r, SEXP nuStarting_r, 
+                   SEXP zLongIndx_r, SEXP betaStarIndx_r, SEXP betaLevelIndx_r, 
+                   SEXP alphaStarIndx_r, SEXP alphaLevelIndx_r, SEXP muBeta_r, SEXP muAlpha_r, 
+                   SEXP SigmaBeta_r, SEXP SigmaAlpha_r, SEXP phiA_r, SEXP phiB_r, 
+                   SEXP sigmaSqA_r, SEXP sigmaSqB_r, SEXP nuA_r, SEXP nuB_r, 
+                   SEXP sigmaSqPsiA_r, SEXP sigmaSqPsiB_r, 
+                   SEXP sigmaSqPA_r, SEXP sigmaSqPB_r, 
+                   SEXP tuning_r, SEXP covModel_r, SEXP nBatch_r, 
+                   SEXP batchLength_r, SEXP acceptRate_r, SEXP nThreads_r, SEXP verbose_r, 
+                   SEXP nReport_r, SEXP samplesInfo_r, SEXP chainInfo_r, SEXP fixedParams_r, 
+                   SEXP sigmaSqIG_r, SEXP gridIndx_r){
    
     /**********************************************************************
      * Initial constants
@@ -186,7 +186,7 @@ extern "C" {
         Rprintf("----------------------------------------\n");
         Rprintf("\tModel description\n");
         Rprintf("----------------------------------------\n");
-        Rprintf("NNGP Occupancy model with Polya-Gamma latent\nvariable fit with %i sites.\n\n", J);
+        Rprintf("NNGP Spatial Occupancy model with Polya-Gamma latent\nvariable fit with %i sites.\n\n", J);
         Rprintf("Samples per chain: %i (%i batches of length %i)\n", nSamples, nBatch, batchLength);
         Rprintf("Burn-in: %i \n", nBurn); 
         Rprintf("Thinning Rate: %i \n", nThin); 
@@ -700,7 +700,7 @@ extern "C" {
 	if (!fixedParams[3]) {
           if (sigmaSqIG) {
 #ifdef _OPENMP
-#pragma omp parallel for private (e, i, b) reduction(+:a, logDet)
+#pragma omp parallel for private (e, i, b) reduction(+:a)
 #endif
             for (j = 0; j < Jw; j++){
               if(nnIndxLU[Jw+j] > 0){
