@@ -63,27 +63,27 @@ void updateBFSVCT(double *B, double *F, double *c, double *C, double *coords, in
 
 extern "C" {
   SEXP svcTPGOccNNGP(SEXP y_r, SEXP X_r, SEXP Xw_r, SEXP Xp_r, SEXP coords_r, SEXP XRE_r, 
-		     SEXP XpRE_r, SEXP consts_r, 
-	             SEXP K_r, SEXP nOccRELong_r, SEXP nDetRELong_r, 
-		     SEXP m_r, SEXP nnIndx_r, SEXP nnIndxLU_r, 
-		     SEXP uIndx_r, SEXP uIndxLU_r, SEXP uiIndx_r,
-		     SEXP betaStarting_r, SEXP alphaStarting_r, 
-		     SEXP sigmaSqPsiStarting_r, SEXP sigmaSqPStarting_r,
-		     SEXP betaStarStarting_r, SEXP alphaStarStarting_r,
-	             SEXP phiStarting_r, SEXP sigmaSqStarting_r, SEXP nuStarting_r, 
-		     SEXP wStarting_r, SEXP zStarting_r, 
-	             SEXP zLongIndx_r, SEXP zYearIndx_r, SEXP zDatIndx_r, 
-		     SEXP betaStarIndx_r, SEXP betaLevelIndx_r, 
-		     SEXP alphaStarIndx_r, SEXP alphaLevelIndx_r, 
-		     SEXP muBeta_r, SEXP SigmaBeta_r, 
-		     SEXP muAlpha_r, SEXP SigmaAlpha_r, 
-		     SEXP phiA_r, SEXP phiB_r, SEXP sigmaSqA_r, SEXP sigmaSqB_r,
-		     SEXP nuA_r, SEXP nuB_r, SEXP sigmaSqPsiA_r, SEXP sigmaSqPsiB_r, 
-		     SEXP sigmaSqPA_r, SEXP sigmaSqPB_r, SEXP ar1Vals_r,
-		     SEXP tuning_r, SEXP covModel_r, SEXP nBatch_r, 
-	             SEXP batchLength_r, SEXP acceptRate_r, SEXP nThreads_r, SEXP verbose_r, 
-	             SEXP nReport_r, SEXP nBurn_r, SEXP nThin_r, SEXP nPost_r, 
-		     SEXP currChain_r, SEXP nChain_r, SEXP sigmaSqIG_r, SEXP gridIndx_r){
+                     SEXP XpRE_r, SEXP consts_r, 
+                     SEXP K_r, SEXP nOccRELong_r, SEXP nDetRELong_r, 
+                     SEXP m_r, SEXP nnIndx_r, SEXP nnIndxLU_r, 
+                     SEXP uIndx_r, SEXP uIndxLU_r, SEXP uiIndx_r,
+                     SEXP betaStarting_r, SEXP alphaStarting_r, 
+                     SEXP sigmaSqPsiStarting_r, SEXP sigmaSqPStarting_r,
+                     SEXP betaStarStarting_r, SEXP alphaStarStarting_r,
+                     SEXP phiStarting_r, SEXP sigmaSqStarting_r, SEXP nuStarting_r, 
+                     SEXP wStarting_r, SEXP zStarting_r, 
+                     SEXP zLongIndx_r, SEXP zYearIndx_r, SEXP zDatIndx_r, 
+                     SEXP betaStarIndx_r, SEXP betaLevelIndx_r, 
+                     SEXP alphaStarIndx_r, SEXP alphaLevelIndx_r, 
+                     SEXP muBeta_r, SEXP SigmaBeta_r, 
+                     SEXP muAlpha_r, SEXP SigmaAlpha_r, 
+                     SEXP phiA_r, SEXP phiB_r, SEXP sigmaSqA_r, SEXP sigmaSqB_r,
+                     SEXP nuA_r, SEXP nuB_r, SEXP sigmaSqPsiA_r, SEXP sigmaSqPsiB_r, 
+                     SEXP sigmaSqPA_r, SEXP sigmaSqPB_r, SEXP ar1Vals_r,
+                     SEXP tuning_r, SEXP covModel_r, SEXP nBatch_r, 
+                     SEXP batchLength_r, SEXP acceptRate_r, SEXP nThreads_r, SEXP verbose_r, 
+                     SEXP nReport_r, SEXP nBurn_r, SEXP nThin_r, SEXP nPost_r, 
+                     SEXP currChain_r, SEXP nChain_r, SEXP sigmaSqIG_r, SEXP gridIndx_r){
    
     /**********************************************************************
      * Initial constants
@@ -1236,7 +1236,7 @@ extern "C" {
       if (ar1 == 1) {
         // Only need to do rho since sigmaSqT is not an MH parameter 
         REAL(acceptSamples_r)[s * rhoIndx] = accept[rhoIndx]/batchLength; 
-        REAL(tuningSamples_r)[s * rhoIndx] = tuning[rhoIndx]; 
+        REAL(tuningSamples_r)[s * rhoIndx] = tuning[j * rhoIndx]; 
         if (accept[rhoIndx] / batchLength > acceptRate) {
           tuning[rhoIndx] += std::min(0.01, 1.0/sqrt(static_cast<double>(s)));
         } else{
@@ -1360,4 +1360,3 @@ extern "C" {
     return(result_r);
   }
 }
-
